.. _contact:

.. raw:: html

    <br>

.. title:: contact


.. raw:: html

    <center>

contact
#######

.. raw:: html

    </center>
    <br>

.. image:: bart.jpg
    :scale: 10%
    :align: right

| Bartholomeus Henricus Julius Thate (bart) - :ref:`evrm <evrm>`
| botfather on #dunkbots irc.freenode.net
| bthate@dds.nl, thatebart@gmail.com

